package geo.profile.data;

import geo.profile.Perfil;

import java.util.Vector;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteDatabase.CursorFactory;
import android.database.sqlite.SQLiteOpenHelper;

public class PerfilSQLiteHelper extends SQLiteOpenHelper {
	 
    //Sentencia SQL para crear la tabla de Usuarios
    String sqlCreate = "CREATE TABLE Perfil (id INTEGER PRIMARY KEY, nombre TEXT, por_hora INT," +
    		" hora_inicio TEXT, hora_fin TEXT, dias_repeticion_horas TEXT, por_gps INT, radio REAL," +
    		" longitud REAL, latitud REAL, dias_repeticion_gps TEXT, wifi INT, tres_g INT, bluetooth INT," +
    		" modo_avion INT, vibrador INT, volumen INTEGER," +
    		" contestador INT, desvio_siempre INT, telefono_siempre TEXT, desvio_ocupada INT, " +
    		" telefono_ocupada TEXT, desvio_sin_respuesta INT, telefono_sin_respuesta TEXT, " +
    		" retraso TEXT, desvio_sin_conexion INT, telefono_sin_conexion TEXT, " +
    		" gtalk INT, whatsapp INT, facebook_msn INT)";
 
    public PerfilSQLiteHelper(Context contexto, String nombre,
                               CursorFactory factory, int version) {
        super(contexto, nombre, factory, version);
    }
 
    @Override
    public void onCreate(SQLiteDatabase db) {
        //Se ejecuta la sentencia SQL de creacin de la tabla
        db.execSQL(sqlCreate);
    }
 
    @Override
    public void onUpgrade(SQLiteDatabase db, int versionAnterior, int versionNueva) {
        //NOTA: Por simplicidad del ejemplo aqu utilizamos directamente la opcin de
        //      eliminar la tabla anterior y crearla de nuevo vaca con el nuevo formato.
        //      Sin embargo lo normal ser que haya que migrar datos de la tabla antigua
        //      a la nueva, por lo que este mtodo debera ser ms elaborado.
 
        //Se elimina la versin anterior de la tabla
        db.execSQL("DROP TABLE IF EXISTS Perfil");
 
        //Se crea la nueva versin de la tabla
        db.execSQL(sqlCreate);
    }
    
    //Obtener la informacin del perfil, a partir de un id
    public String[] getPerfil(int id) {
    	
    	int i = 29;
		String[] result = new String[i];
		 
		SQLiteDatabase db = getReadableDatabase();
		Cursor cursor = db.rawQuery("SELECT nombre, por_hora, hora_inicio, hora_fin, dias_repeticion_horas," +
  		 	" por_gps, radio, longitud, latitud, dias_repeticion_gps, wifi, tres_g, bluetooth, modo_avion," +
  		 	" vibrador, volumen, contestador, desvio_siempre, telefono_siempre, desvio_ocupada, " +
    		" telefono_ocupada , desvio_sin_respuesta, telefono_sin_respuesta, retraso, desvio_sin_conexion," +
    		" telefono_sin_conexion, gtalk, whatsapp, facebook_msn FROM Perfil WHERE id = " +id, null);
		
        if (cursor.moveToNext()){
        	for(int j = 0; j < i; j++){
        		result[j] = cursor.getString(j);
        	}
        }
        cursor.close();
        db.close();
        return result;
	 }

  	 //Actualizar el perfil
	 public void updatePerfil(Perfil p) {
		 SQLiteDatabase db = getWritableDatabase();
		 
		 String [] args = {p.getId().toString()};
		 
		//Creamos el registro a insertar como objeto ContentValues
		 ContentValues registro = new ContentValues();
		 registro.put("nombre", p.getNombre());
		 registro.put("por_hora", p.getPorHora());
		 registro.put("hora_inicio", p.getHoraInicio());
		 registro.put("hora_fin", p.getHoraFin());
		 registro.put("dias_repeticion_horas", p.getDiasRepeticionHoras());
		 registro.put("por_gps", p.getPorGps());
		 registro.put("radio", p.getRadio());
		 registro.put("longitud", p.getLongitud());
		 registro.put("latitud", p.getLatitud());
		 registro.put("dias_repeticion_gps", p.getDiasRepeticionGps());
		 registro.put("wifi", p.getWifi());
		 registro.put("tres_g", p.getTresG());
		 registro.put("bluetooth", p.getBluetooth());
		 registro.put("modo_avion", p.getModoAvion());
		 registro.put("vibrador", p.getVibrador());
		 registro.put("volumen", p.getVolumen());
		 registro.put("contestador", p.getContestador());
		 registro.put("desvio_siempre", p.getDesvioSiempre());
		 registro.put("telefono_siempre", p.getTelefonoSiempre());
		 registro.put("desvio_ocupada", p.getDesvioOcupada());
		 registro.put("telefono_ocupada", p.getTelefonoOcupada());
		 registro.put("desvio_sin_respuesta", p.getDesvioSinRespuesta());
		 registro.put("telefono_sin_respuesta", p.getTelefonoSinRespuesta());
		 registro.put("retraso", p.getRetraso());
		 registro.put("desvio_sin_conexion", p.getDesvioSinConexion());
		 registro.put("telefono_sin_conexion", p.getTelefonoSinConexion());
		 registro.put("gtalk", p.getGTalk());
		 registro.put("whatsapp", p.getWhatsApp());
		 registro.put("facebook_msn", p.getFacebookMSN());
		 
		 //Actualizamos el registro en la base de datos
		 db.update("Perfil", registro, "id= ?", args);
		 
	 }
	 
	 public void updatePerfilPorHora(Perfil p) {
		 SQLiteDatabase db = getWritableDatabase();
		 
		 String [] args = {p.getId().toString()};
		 
		//Creamos el registro a insertar como objeto ContentValues
		 ContentValues registro = new ContentValues();
		 registro.put("por_hora", p.getPorHora());
		 registro.put("hora_inicio", p.getHoraInicio());
		 registro.put("hora_fin", p.getHoraFin());
		 //Actualizamos el registro en la base de datos
		 db.update("Perfil", registro, "id= ?", args);
			
		}
	 
	 public void updatePerfilRepetir(Perfil p) {
		 SQLiteDatabase db = getWritableDatabase();
		 
		 String [] args = {p.getId().toString()};
		 
		//Creamos el registro a insertar como objeto ContentValues
		 ContentValues registro = new ContentValues();
		 registro.put("dias_repeticion_horas", p.getDiasRepeticionHoras());
		 registro.put("dias_repeticion_gps", p.getDiasRepeticionGps());
		 //Actualizamos el registro en la base de datos
		 db.update("Perfil", registro, "id= ?", args);
			
		}
	 
	 public void updatePerfilPorLocalizacion(Perfil p) {
		 SQLiteDatabase db = getWritableDatabase();
		 
		 String [] args = {p.getId().toString()};
		 
		//Creamos el registro a insertar como objeto ContentValues
		 ContentValues registro = new ContentValues();
		 registro.put("por_gps", p.getPorGps());
		 registro.put("radio", p.getRadio());
		 registro.put("longitud", p.getLongitud());
		 registro.put("latitud", p.getLatitud());
		 //Actualizamos el registro en la base de datos
		 db.update("Perfil", registro, "id= ?", args);
			
		}
	 
	 public void updatePerfilSonido(Perfil p) {
		 SQLiteDatabase db = getWritableDatabase();
		 
		 String [] args = {p.getId().toString()};
		 
		//Creamos el registro a insertar como objeto ContentValues
		 ContentValues registro = new ContentValues();
		 registro.put("vibrador", p.getVibrador());
		 registro.put("volumen", p.getVolumen());
		 //Actualizamos el registro en la base de datos
		 db.update("Perfil", registro, "id= ?", args);
			
		}
	 
	 public void updatePerfilConexionesInalambricas(Perfil p) {
		 SQLiteDatabase db = getWritableDatabase();
		 
		 String [] args = {p.getId().toString()};
		 
		//Creamos el registro a insertar como objeto ContentValues
		 ContentValues registro = new ContentValues();
		 registro.put("wifi", p.getWifi());
		 registro.put("tres_g", p.getTresG());
		 registro.put("bluetooth", p.getBluetooth());
		 //Actualizamos el registro en la base de datos
		 db.update("Perfil", registro, "id= ?", args);
			
		}
	 
	 public void updatePerfilModoAvion(Perfil p) {
		 SQLiteDatabase db = getWritableDatabase();
		 
		 String [] args = {p.getId().toString()};
		 
		//Creamos el registro a insertar como objeto ContentValues
		 ContentValues registro = new ContentValues();
		 registro.put("modo_avion", p.getModoAvion());
		 //Actualizamos el registro en la base de datos
		 db.update("Perfil", registro, "id= ?", args);
			
		}
	 
	 public void updatePerfilContestador(Perfil p) {
		 SQLiteDatabase db = getWritableDatabase();
		 
		 String [] args = {p.getId().toString()};
		 
		//Creamos el registro a insertar como objeto ContentValues
		 ContentValues registro = new ContentValues();
		 registro.put("contestador", p.getContestador());
		 //Actualizamos el registro en la base de datos
		 db.update("Perfil", registro, "id= ?", args);
			
		}
	 
	 public void updatePerfilDesvioSiempre(Perfil p) {
		 SQLiteDatabase db = getWritableDatabase();
		 
		 String [] args = {p.getId().toString()};
		 
		//Creamos el registro a insertar como objeto ContentValues
		 
		 ContentValues registro = new ContentValues();
		 registro.put("desvio_siempre", p.getDesvioSiempre());
		 registro.put("telefono_siempre", p.getTelefonoSiempre());
		 //Actualizamos el registro en la base de datos
		 db.update("Perfil", registro, "id= ?", args);
			
		}
	 
	 public void updatePerfilDesvioOcupada(Perfil p) {
		 SQLiteDatabase db = getWritableDatabase();
		 
		 String [] args = {p.getId().toString()};
		 
		//Creamos el registro a insertar como objeto ContentValues
		 
		 ContentValues registro = new ContentValues();
		 registro.put("desvio_ocupada", p.getDesvioOcupada());
		 registro.put("telefono_ocupada", p.getTelefonoOcupada());
		 //Actualizamos el registro en la base de datos
		 db.update("Perfil", registro, "id= ?", args);
			
		}
	 
	 public void updatePerfilDesvioSinRespuesta(Perfil p) {
		 SQLiteDatabase db = getWritableDatabase();
		 
		 String [] args = {p.getId().toString()};
		 
		//Creamos el registro a insertar como objeto ContentValues
		 
		 ContentValues registro = new ContentValues();
		 registro.put("desvio_sin_respuesta", p.getDesvioSinRespuesta());
		 registro.put("telefono_sin_respuesta", p.getTelefonoSinRespuesta());
		 registro.put("retraso", p.getRetraso());
		 //Actualizamos el registro en la base de datos
		 db.update("Perfil", registro, "id= ?", args);
			
		}
	 
	 public void updatePerfilDesvioSinConexion(Perfil p) {
		 SQLiteDatabase db = getWritableDatabase();
		 
		 String [] args = {p.getId().toString()};
		 
		//Creamos el registro a insertar como objeto ContentValues
		 
		 ContentValues registro = new ContentValues();
		 registro.put("desvio_sin_conexion", p.getDesvioSinConexion());
		 registro.put("telefono_sin_conexion", p.getTelefonoSinConexion());
		 //Actualizamos el registro en la base de datos
		 db.update("Perfil", registro, "id= ?", args);
			
		}
	 
	 public void updatePerfilMensajeriaInstantanea(Perfil p) {
		 SQLiteDatabase db = getWritableDatabase();
		 
		 String [] args = {p.getId().toString()};
		 
		//Creamos el registro a insertar como objeto ContentValues
		 ContentValues registro = new ContentValues();
		 registro.put("gtalk", p.getGTalk());
		 registro.put("whatsapp", p.getWhatsApp());
		 registro.put("facebook_msn", p.getFacebookMSN());
		 //Actualizamos el registro en la base de datos
		 db.update("Perfil", registro, "id= ?", args);
			
		}
	 
	 //Almacenar perfil
	 public Integer savePerfil(Perfil p) {
		 Integer res;
		 SQLiteDatabase db = getWritableDatabase();
		 
		 //Creamos el registro a insertar como objeto ContentValues
		 ContentValues registro = new ContentValues();
		 registro.put("nombre", p.getNombre());
		 registro.put("por_hora", p.getPorHora());
		 registro.put("hora_inicio", p.getHoraInicio());
		 registro.put("hora_fin", p.getHoraFin());
		 registro.put("dias_repeticion_horas", p.getDiasRepeticionHoras());
		 registro.put("por_gps", p.getPorGps());
		 registro.put("radio", p.getRadio());
		 registro.put("longitud", p.getLongitud());
		 registro.put("latitud", p.getLatitud());
		 registro.put("dias_repeticion_gps", p.getDiasRepeticionGps());
		 registro.put("wifi", p.getWifi());
		 registro.put("tres_g", p.getTresG());
		 registro.put("bluetooth", p.getBluetooth());
		 registro.put("modo_avion", p.getModoAvion());
		 registro.put("vibrador", p.getVibrador());
		 registro.put("volumen", p.getVolumen());
		 registro.put("contestador", p.getContestador());
		 registro.put("desvio_siempre", p.getDesvioSiempre());
		 registro.put("telefono_siempre", p.getTelefonoSiempre());
		 registro.put("desvio_ocupada", p.getDesvioOcupada());
		 registro.put("telefono_ocupada", p.getTelefonoOcupada());
		 registro.put("desvio_sin_respuesta", p.getDesvioSinRespuesta());
		 registro.put("telefono_sin_respuesta", p.getTelefonoSinRespuesta());
		 registro.put("retraso", p.getRetraso());
		 registro.put("desvio_sin_conexion", p.getDesvioSinConexion());
		 registro.put("telefono_sin_conexion", p.getTelefonoSinConexion());
		 registro.put("gtalk", p.getGTalk());
		 registro.put("whatsapp", p.getWhatsApp());
		 registro.put("facebook_msn", p.getFacebookMSN());
		 
		 //Insertamos el registro en la base de datos
		 Long resultado = db.insert("Perfil", null, registro);
		 res = Integer.parseInt(resultado.toString());
		  
		 return res;
	}
	 
	//Borrar un perfil
	 public void deletePerfil(Perfil p, Integer idPerfil) {
		 SQLiteDatabase db = getWritableDatabase();
		 db.delete("Perfil", "id = "+idPerfil, null);
	 }
    
   	 //Listar los perfiles
  	public Vector<String[]> listPerfiles(int cantidad) {
  		
         Vector<String[]> result = new Vector<String[]>();
         SQLiteDatabase db = getReadableDatabase();
         Cursor cursor = db.rawQuery("SELECT id, nombre FROM Perfil ORDER BY nombre DESC LIMIT " +cantidad, null);
         while (cursor.moveToNext()){
          	result.add(new String[]{cursor.getString(0), cursor.getString(1)});
          }
         db.close();
         cursor.close();
         return result;
  	}     
    
    //Obtener todos los perfiles
  	 public Perfil[] getAllPerfiles() {
  		 
  		 SQLiteDatabase db = getReadableDatabase();
  		 Cursor cursor = db.rawQuery("SELECT id, nombre, por_hora, hora_inicio, hora_fin, dias_repeticion_horas," +
  		 	" por_gps, radio, longitud, latitud, dias_repeticion_gps, wifi, tres_g, bluetooth, modo_avion," +
  		 	" vibrador, volumen, contestador, desvio_siempre, telefono_siempre, desvio_ocupada, " +
    		" telefono_ocupada , desvio_sin_respuesta, telefono_sin_respuesta, retraso, desvio_sin_conexion," +
    		" telefono_sin_conexion, gtalk, whatsapp, facebook_msn FROM Perfil", null);
  		 
  		Perfil[] perfiles = new Perfil[cursor.getCount()];
  		 
  		 int i = 0;
  		 while(cursor.moveToNext()) {
  			 Perfil p = new Perfil();
  			 p.setId(cursor.getInt(0));
  			 p.setNombre(cursor.getString(1));
  			 p.setPorHora(cursor.getInt(2));
  			 p.setHoraInicio(cursor.getString(3));
  			 p.setHoraFin(cursor.getString(4));
  			 p.setDiasRepeticionHoras(cursor.getString(5));
  			 p.setPorGps(cursor.getInt(6));
  			 p.setRadio(cursor.getDouble(7));
  			 p.setLongitud(cursor.getDouble(8));
  			 p.setLatitud(cursor.getDouble(9));
  			 p.setDiasRepeticionGps(cursor.getString(10));
  			 p.setWifi(cursor.getInt(11));
  			 p.setTresG(cursor.getInt(12));
  			 p.setBluetooth(cursor.getInt(13));
  			 p.setModoAvion(cursor.getInt(14));
  			 p.setVibrador(cursor.getInt(15));
  			 p.setVolumen(cursor.getInt(16));
  			 p.setContestador(cursor.getInt(17));
  			 p.setDesvioSiempre(cursor.getInt(18));
  			 p.setTelefonoSiempre(cursor.getString(19));
  			 p.setDesvioOcupada(cursor.getInt(20));
  			 p.setTelefonoOcupada(cursor.getString(21));
  			 p.setDesvioSinRespuesta(cursor.getInt(22));
  			 p.setTelefonoSinRespuesta(cursor.getString(23));
  			 p.setRetraso(cursor.getString(24));
  			 p.setDesvioSinConexion(cursor.getInt(25));
  			 p.setTelefonoSinConexion(cursor.getString(26));
  			 p.setGTalk(cursor.getInt(27));
  			 p.setWhatsApp(cursor.getInt(28));
  			 p.setFacebookMSN(cursor.getInt(29));
  			
  			perfiles[i] = p;
  			 i++;
  		 }
  		 
  		 cursor.close();  	
  		 db.close();
  		 return perfiles;
  	 }
  	 
  	public boolean getNombreRepetido(String nombreRepetido) {
  		boolean res = false;
        SQLiteDatabase db = getReadableDatabase();
        Cursor cursor = db.rawQuery("SELECT id, nombre FROM Perfil WHERE nombre ='" +nombreRepetido+ "'", null);
        while (cursor.moveToNext()){
        	res= true;
         }
        cursor.close();
        db.close();
        return res;
	}

	public String[] buscarPorHora(Perfil perfil) {
		int i = 3;
		String [] res = new String[i];

        SQLiteDatabase db = getReadableDatabase();
        Cursor cursor = db.rawQuery("SELECT por_hora, hora_inicio, hora_fin FROM Perfil WHERE id = " +perfil.getId(), null);
		
        if (cursor.moveToNext()){
        	for(int j = 0; j < i; j++){
        		res[j] = cursor.getString(j);
        	}
        }

        cursor.close();
        db.close();
        return res;
        
	}
	
	public String[] buscarRepetir(Perfil perfil) {
		int i = 2;
		String [] res = new String[i];

        SQLiteDatabase db = getReadableDatabase();
        Cursor cursor = db.rawQuery("SELECT dias_repeticion_horas, dias_repeticion_gps FROM Perfil WHERE id = " +perfil.getId(), null);
		
        if (cursor.moveToNext()){
        	for(int j = 0; j < i; j++){
        		res[j] = cursor.getString(j);
        	}
        }

        cursor.close();
        db.close();
        return res;
        
	}
	
	public Double[] buscarPorLocalizacion(Perfil perfil) {
		int i = 4;
		Double [] res = new Double[i];

        SQLiteDatabase db = getReadableDatabase();
        Cursor cursor = db.rawQuery("SELECT por_gps, radio, longitud, latitud FROM Perfil WHERE id = " +perfil.getId(), null);
		
        if (cursor.moveToNext()){
        	for(int j = 0; j < i; j++){
        		res[j] = cursor.getDouble(j);
        	}
        }

        cursor.close();
        db.close();
        return res;
        
	}
	
	public String[] buscarSonido(Perfil perfil) {
		int i = 2;
		String [] res = new String[i];

        SQLiteDatabase db = getReadableDatabase();
        Cursor cursor = db.rawQuery("SELECT vibrador, volumen FROM Perfil WHERE id = " +perfil.getId(), null);
		
        if (cursor.moveToNext()){
        	for(int j = 0; j < i; j++){
        		res[j] = cursor.getString(j);
        	}
        }

        cursor.close();
        db.close();
        return res;
        
	}
	
	public String[] buscarConexionesInalambricas(Perfil perfil) {
		int i = 3;
		String [] res = new String[i];

        SQLiteDatabase db = getReadableDatabase();
        Cursor cursor = db.rawQuery("SELECT wifi, tres_g, bluetooth FROM Perfil WHERE id = " +perfil.getId(), null);
		
        if (cursor.moveToNext()){
        	for(int j = 0; j < i; j++){
        		res[j] = cursor.getString(j);
        	}
        }

        cursor.close();
        db.close();
        return res;
        
	}
	
	public String[] buscarModoAvion(Perfil perfil) {
		int i = 1;
		String [] res = new String[i];

        SQLiteDatabase db = getReadableDatabase();
        Cursor cursor = db.rawQuery("SELECT modo_avion FROM Perfil WHERE id = " +perfil.getId(), null);
		
        if (cursor.moveToNext()){
        	for(int j = 0; j < i; j++){
        		res[j] = cursor.getString(j);
        	}
        }

        cursor.close();
        db.close();
        return res;
        
	}
	
	public String[] buscarContestador(Perfil perfil) {
		int i = 1;
		String [] res = new String[i];

        SQLiteDatabase db = getReadableDatabase();
        Cursor cursor = db.rawQuery("SELECT contestador FROM Perfil WHERE id = " +perfil.getId(), null);
		
        if (cursor.moveToNext()){
        	for(int j = 0; j < i; j++){
        		res[j] = cursor.getString(j);
        	}
        }

        cursor.close();
        db.close();
        return res;
        
	}
	
	public String[] buscarDesvio(Perfil perfil) {
		int i = 9;
		String [] res = new String[i];

        SQLiteDatabase db = getReadableDatabase();
        Cursor cursor = db.rawQuery("SELECT desvio_siempre, telefono_siempre, desvio_ocupada, telefono_ocupada," +
        		"desvio_sin_respuesta, telefono_sin_respuesta, retraso, desvio_sin_conexion, telefono_sin_conexion" +
        		" FROM Perfil WHERE id = " +perfil.getId(), null);
		
        if (cursor.moveToNext()){
        	for(int j = 0; j < i; j++){
        		res[j] = cursor.getString(j);
        	}
        }

        cursor.close();
        db.close();
        return res;
        
	}

	public String[] buscarMensajeriaInstatanea(Perfil perfil) {
		int i = 3;
		String [] res = new String[i];

        SQLiteDatabase db = getReadableDatabase();
        Cursor cursor = db.rawQuery("SELECT gtalk, whatsapp, facebook_msn FROM Perfil WHERE id = " +perfil.getId(), null);
		
        if (cursor.moveToNext()){
        	for(int j = 0; j < i; j++){
        		res[j] = cursor.getString(j);
        	}
        }

        cursor.close();
        db.close();
        return res;
        
	}
}
